<?php

namespace App\Controller;

use App\DataObjects\TicketFormData;
use App\Service\TicketService;
use Stripe\Stripe;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\Serializer\SerializerInterface;

final class TicketController extends AbstractController
{
    public function __construct(
        private TicketService $service,
        private SerializerInterface $serializer,
    ) {
    }

    #[Route('/ticket', name: 'app_ticket')]
    public function index(): Response
    {
        return $this->render('ticket/index.html.twig');
    }

    #[Route(path: '/ticket/submit', name: 'app_submit', methods: Request::METHOD_POST)]
    public function submit(Request $request): Response
    {
        $ticketData = $this->serializer->deserialize($request->getContent(), TicketFormData::class, 'json');

        return $this->json(['id' => $this->service->handleTicketData($ticketData)->id]);
    }

    #[Route(path: '/success', name: 'app_success', methods: Request::METHOD_GET)]
    public function success(Request $request): Response
    {
        $sessionId = $request->query->get('session_id');

        if (!$sessionId) {
            noty()->error('Etwas ist schiefgelaufen');

            return $this->redirectToRoute('app_ticket');
        }

        if (!$this->service->completePayment($sessionId)) {
            noty()->error('Etwas ist schiefgelaufen');

            return $this->redirectToRoute('app_ticket');
        }

        return $this->render('ticket/success.html.twig');
    }

    #[Route(path: '/cancelled', name: 'app_cancelled', methods: Request::METHOD_GET)]
    public function cancel(): Response
    {
        noty()->error('Bezahlung abgebrochen');

        return $this->redirectToRoute('app_ticket');
    }
}
